/*
 * Copyright 2010-2011 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.servlet;

import com.squeakysand.commons.io.FileHelper;

import java.io.File;
import java.io.IOException;

import javax.servlet.ServletContext;
import javax.servlet.ServletOutputStream;
import javax.servlet.ServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class FileServletHelper {

    private static final Logger LOG = LoggerFactory.getLogger(FileServletHelper.class);

    /**
     * @param virtualFilePath the absolute path to the file relative to the root of the WAR file, for example <code>/index.html</code>.
     */
    public static void writeFileAsServletResponse(String virtualFilePath, ServletContext servletContext, ServletResponse response) throws IOException {
        String realFilePath = servletContext.getRealPath(virtualFilePath);
        LOG.info("realFilePath: {}", realFilePath);
        File file = new File(realFilePath);
        String mimeType = servletContext.getMimeType(realFilePath);
        writeFileAsServletResponse(file, mimeType, response);
    }

    public static void writeFileAsServletResponse(File file, String mimeType, ServletResponse response) throws IOException {
        response.setContentType(mimeType);
        response.setContentLength((int)file.length());
        ServletOutputStream outputStream = response.getOutputStream();
        FileHelper.writeFileToStream(file, outputStream);
    }

}
